@@ -395,14 +395,14 @@ static inline void _find_and_check_platforms(cl_uint num_icds) {
     picd->ext_fn_ptr = _get_function_addr(dlh, NULL, "clGetExtensionFunctionAddress");
     clIcdGetPlatformIDsKHR_fn plt_fn_ptr =
       _get_function_addr(dlh, picd->ext_fn_ptr, "clIcdGetPlatformIDsKHR");
-    clGetPlatformInfo_fn plt_info_ptr =
-      _get_function_addr(dlh, picd->ext_fn_ptr,	"clGetPlatformInfo");
     if( picd->ext_fn_ptr == NULL
-	|| plt_fn_ptr == NULL
-	|| plt_info_ptr == NULL) {
+       || plt_fn_ptr == NULL) {
       debug(D_WARN, "Missing symbols in ICD, skipping it");
       continue;
     }
+    int plt_info_global_ptr_queried = 0;
+    clGetPlatformInfo_fn plt_info_global_ptr = NULL;
+      _get_function_addr(dlh, picd->ext_fn_ptr,	"clGetPlatformInfo");
     cl_uint num_platforms=0;
     cl_int error;
     error = (*plt_fn_ptr)(0, NULL, &num_platforms);
@@ -422,7 +422,7 @@ static inline void _find_and_check_platforms(cl_uint num_icds) {
     debug(D_LOG, "Try to load %d platforms", num_platforms);
     if (_allocate_platforms(num_platforms) < num_platforms) {
       free(platforms);
-      debug(D_WARN, "Not enought platform allocated. Skipping ICD");
+      debug(D_WARN, "Not enough platform allocated. Skipping ICD");
       continue;
     }
     for(j=0; j<num_platforms; j++) {
@@ -432,6 +432,27 @@ static inline void _find_and_check_platforms(cl_uint num_icds) {
       p->extension_suffix=NULL;
       p->vicd=&_icds[i];
       p->pid=platforms[j];
+
+      /* By default, we try to use the plateform-specific
+       * clGetPlatformInfo (from the dispatch table).
+       * If missing, we fail back on the global one (if any)
+       */
+      clGetPlatformInfo_fn plt_info_ptr = p->pid->dispatch->clGetPlatformInfo;
+
+      if (plt_info_ptr == NULL) {
+        if (! plt_info_global_ptr_queried) {
+          plt_info_global_ptr =
+            _get_function_addr(dlh, picd->ext_fn_ptr, "clGetPlatformInfo");
+            plt_info_global_ptr_queried = 1;
+        }
+        if (plt_info_global_ptr) {
+          plt_info_ptr = plt_info_global_ptr;
+        } else {
+          debug(D_WARN, "Missing clGetPlatformInfo in ICD, skipping it");
+          continue;
+        }
+      }
+
 #ifdef DEBUG_OCL_ICD
       if (debug_ocl_icd_mask & D_DUMP) {
         int log=debug_ocl_icd_mask & D_TRACE;
@@ -705,13 +726,13 @@ static cl_int clGetICDLoaderInfoOCLICD(
   void *           param_value,
   size_t *         param_value_size_ret)
 {
-  char cl_icdl_ocl_version[] = "OpenCL " OCL_ICD_OPENCL_VERSION;
-  char cl_icdl_version[] = PACKAGE_VERSION;
-  char cl_icdl_name[] = PACKAGE_NAME;
-  char cl_icdl_vendor[] = "OCL Icd free software";
+  static const char cl_icdl_ocl_version[] = "OpenCL " OCL_ICD_OPENCL_VERSION;
+  static const char cl_icdl_version[] = PACKAGE_VERSION;
+  static const char cl_icdl_name[] = PACKAGE_NAME;
+  static const char cl_icdl_vendor[] = "OCL Icd free software";
 
   size_t size_string;
-  char * string_p;
+  const char * string_p;
 #define oclcase(name, NAME) \
   case CL_ICDL_##NAME: \
     string_p = cl_icdl_##name; \
